@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2000, 2021, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -350,6 +350,10 @@ public class GIFImageReader extends ImageReader {
                     int off = 0;
                     while (left > 0) {
                         int nbytes = stream.read(block, off, left);
+                        if (nbytes == -1) {
+                            throw new IIOException("Invalid block length for " +
+                                    "LZW encoded image data");
+                        }
                         off += nbytes;
                         left -= nbytes;
                     }
@@ -930,6 +934,10 @@ public class GIFImageReader extends ImageReader {
             int off = 0;
             while (left > 0) {
                 int nbytes = stream.read(block, off, left);
+                if (nbytes == -1) {
+                    throw new IIOException("Invalid block length for " +
+                            "LZW encoded image data");
+                }
                 left -= nbytes;
                 off += nbytes;
             }
@@ -990,6 +998,11 @@ public class GIFImageReader extends ImageReader {
                         }
                     }
 
+                    if (tableIndex >= prefix.length) {
+                        throw new IIOException("Code buffer limit reached,"
+                                + " no End of Image tag present, possibly data is corrupted. ");
+                    }
+
                     int ti = tableIndex;
                     int oc = oldCode;
 
