@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2005, 2022, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -35,12 +35,14 @@ import java.net.URISyntaxException;
 import java.net.URL;
 import java.nio.CharBuffer;
 import java.nio.charset.Charset;
+import java.nio.file.DirectoryStream;
 import java.nio.file.FileSystem;
 import java.nio.file.FileSystems;
 import java.nio.file.FileVisitOption;
 import java.nio.file.FileVisitResult;
 import java.nio.file.Files;
 import java.nio.file.InvalidPathException;
+import java.nio.file.NotDirectoryException;
 import java.nio.file.LinkOption;
 import java.nio.file.Path;
 import java.nio.file.Paths;
@@ -313,7 +315,7 @@ public class JavacFileManager extends BaseFileManager implements StandardJavaFil
                 fs = new DirectoryContainer(realPath);
             } else {
                 try {
-                    fs = new ArchiveContainer(realPath);
+                    fs = new ArchiveContainer(path);
                 } catch (ProviderNotFoundException | SecurityException ex) {
                     throw new IOException(ex);
                 }
@@ -517,21 +519,29 @@ public class JavacFileManager extends BaseFileManager implements StandardJavaFil
             }
             packages = new HashMap<>();
             for (Path root : fileSystem.getRootDirectories()) {
-                Files.walkFileTree(root, EnumSet.noneOf(FileVisitOption.class), Integer.MAX_VALUE,
-                        new SimpleFileVisitor<Path>() {
-                            @Override
-                            public FileVisitResult preVisitDirectory(Path dir, BasicFileAttributes attrs) {
-                                if (isValid(dir.getFileName())) {
-                                    packages.put(new RelativeDirectory(root.relativize(dir).toString()), dir);
-                                    return FileVisitResult.CONTINUE;
-                                } else {
-                                    return FileVisitResult.SKIP_SUBTREE;
-                                }
-                            }
-                        });
+                walkDirectories(root, root);
             }
         }
 
+        private void walkDirectories(Path root, Path p) throws IOException {
+            // Avoid calling Files.isDirectory, Files.exists or another other method
+            // that internally might use Files.readAttributes, as that may cause
+            // additional I/O.
+            if (!isValid(p.getFileName())) {
+                // Note this path is likely to include most non-directories, as those are
+                // likely to include a file extension, and hence won't pass the isValid check.
+                return ;
+            }
+            packages.put(new RelativeDirectory(root.relativize(p).toString()), p);
+            try (DirectoryStream < Path > ds = Files.newDirectoryStream(p)) {
+                for (Path n: ds) {
+                    walkDirectories(root, n);
+                }
+            } catch (NotDirectoryException ex) {
+                // Ignore...
+            }
+         }
+
         /**
          * Insert all files in subdirectory subdirectory of this archive
          * which match fileKinds into resultList
