@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.7+8-LTS" },
-            { "jdk", "11.0.7" },
-            { "release", "11.0.7" },
+            { "full", "11.0.17+10-LTS-269" },
+            { "jdk", "11.0.17" },
+            { "release", "11.0.17" },
         };
     }
 }
