@@ -37,10 +37,10 @@ class VersionProps {
         "java";
 
     private static final String java_version =
-        "11.0.8";
+        "11.0.17";
 
     private static final String java_version_date =
-        "2020-07-14";
+        "2022-10-18";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -48,10 +48,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.8+10-LTS";
+        "11.0.17+10-LTS-269";
 
     private static final String VERSION_NUMBER =
-        "11.0.8";
+        "11.0.17";
 
     private static final String VERSION_BUILD =
         "10";
@@ -60,10 +60,10 @@ class VersionProps {
         "";
 
     private static final String VERSION_OPT =
-        "LTS";
+        "LTS-269";
 
     private static final boolean isLTS =
-        "LTS".startsWith("LTS");
+        "LTS-269".startsWith("LTS");
 
     // The remaining fields must not be final,
     // so that they can be redefined by jlink plugins
