@@ -775,6 +775,7 @@ class ZoneName {
         "SystemV/YST9YDT", "America/Anchorage",
 
         // From tzdb
+        "Africa/Accra", "Africa/Abidjan",
         "Africa/Addis_Ababa", "Africa/Nairobi",
         "Africa/Asmara", "Africa/Nairobi",
         "Africa/Asmera", "Africa/Nairobi",
@@ -809,48 +810,59 @@ class ZoneName {
         "Africa/Ouagadougou", "Africa/Abidjan",
         "Africa/Porto-Novo", "Africa/Lagos",
         "Africa/Timbuktu", "Africa/Abidjan",
-        "America/Anguilla", "America/Port_of_Spain",
-        "America/Antigua", "America/Port_of_Spain",
+        "America/Anguilla", "America/Puerto_Rico",
+        "America/Antigua", "America/Puerto_Rico",
         "America/Argentina/ComodRivadavia", "America/Argentina/Catamarca",
-        "America/Aruba", "America/Curacao",
+        "America/Aruba", "America/Puerto_Rico",
+        "America/Atikokan", "America/Panama",
         "America/Atka", "America/Adak",
+        "America/Blanc-Sablon", "America/Puerto_Rico",
         "America/Buenos_Aires", "America/Argentina/Buenos_Aires",
         "America/Catamarca", "America/Argentina/Catamarca",
         "America/Cayman", "America/Panama",
-        "America/Coral_Harbour", "America/Atikokan",
+        "America/Coral_Harbour", "America/Panama",
         "America/Cordoba", "America/Argentina/Cordoba",
-        "America/Dominica", "America/Port_of_Spain",
+        "America/Creston", "America/Phoenix",
+        "America/Curacao", "America/Puerto_Rico",
+        "America/Dominica", "America/Puerto_Rico",
         "America/Ensenada", "America/Tijuana",
         "America/Fort_Wayne", "America/Indiana/Indianapolis",
-        "America/Grenada", "America/Port_of_Spain",
-        "America/Guadeloupe", "America/Port_of_Spain",
+        "America/Godthab", "America/Nuuk",
+        "America/Grenada", "America/Puerto_Rico",
+        "America/Guadeloupe", "America/Puerto_Rico",
         "America/Indianapolis", "America/Indiana/Indianapolis",
         "America/Jujuy", "America/Argentina/Jujuy",
         "America/Knox_IN", "America/Indiana/Knox",
-        "America/Kralendijk", "America/Curacao",
+        "America/Kralendijk", "America/Puerto_Rico",
         "America/Louisville", "America/Kentucky/Louisville",
-        "America/Lower_Princes", "America/Curacao",
-        "America/Marigot", "America/Port_of_Spain",
+        "America/Lower_Princes", "America/Puerto_Rico",
+        "America/Marigot", "America/Puerto_Rico",
         "America/Mendoza", "America/Argentina/Mendoza",
         "America/Montreal", "America/Toronto",
-        "America/Montserrat", "America/Port_of_Spain",
+        "America/Montserrat", "America/Puerto_Rico",
+        "America/Nassau", "America/Toronto",
+        "America/Port_of_Spain", "America/Puerto_Rico",
         "America/Porto_Acre", "America/Rio_Branco",
         "America/Rosario", "America/Argentina/Cordoba",
         "America/Santa_Isabel", "America/Tijuana",
         "America/Shiprock", "America/Denver",
-        "America/St_Barthelemy", "America/Port_of_Spain",
-        "America/St_Kitts", "America/Port_of_Spain",
-        "America/St_Lucia", "America/Port_of_Spain",
-        "America/St_Thomas", "America/Port_of_Spain",
-        "America/St_Vincent", "America/Port_of_Spain",
-        "America/Tortola", "America/Port_of_Spain",
-        "America/Virgin", "America/Port_of_Spain",
+        "America/St_Barthelemy", "America/Puerto_Rico",
+        "America/St_Kitts", "America/Puerto_Rico",
+        "America/St_Lucia", "America/Puerto_Rico",
+        "America/St_Thomas", "America/Puerto_Rico",
+        "America/St_Vincent", "America/Puerto_Rico",
+        "America/Tortola", "America/Puerto_Rico",
+        "America/Virgin", "America/Puerto_Rico",
+        "Antarctica/DumontDUrville", "Pacific/Port_Moresby",
         "Antarctica/McMurdo", "Pacific/Auckland",
         "Antarctica/South_Pole", "Pacific/Auckland",
-        "Arctic/Longyearbyen", "Europe/Oslo",
+        "Antarctica/Syowa", "Asia/Riyadh",
+        "Antarctica/Vostok", "Asia/Urumqi",
+        "Arctic/Longyearbyen", "Europe/Berlin",
         "Asia/Aden", "Asia/Riyadh",
         "Asia/Ashkhabad", "Asia/Ashgabat",
         "Asia/Bahrain", "Asia/Qatar",
+        "Asia/Brunei", "Asia/Kuching",
         "Asia/Calcutta", "Asia/Kolkata",
         "Asia/Chongqing", "Asia/Shanghai",
         "Asia/Chungking", "Asia/Shanghai",
@@ -859,6 +871,7 @@ class ZoneName {
         "Asia/Istanbul", "Europe/Istanbul",
         "Asia/Kashgar", "Asia/Urumqi",
         "Asia/Katmandu", "Asia/Kathmandu",
+        "Asia/Kuala_Lumpur", "Asia/Singapore",
         "Asia/Kuwait", "Asia/Riyadh",
         "Asia/Macao", "Asia/Macau",
         "Asia/Muscat", "Asia/Dubai",
@@ -871,10 +884,12 @@ class ZoneName {
         "Asia/Ulan_Bator", "Asia/Ulaanbaatar",
         "Asia/Vientiane", "Asia/Bangkok",
         "Atlantic/Faeroe", "Atlantic/Faroe",
-        "Atlantic/Jan_Mayen", "Europe/Oslo",
+        "Atlantic/Jan_Mayen", "Europe/Berlin",
+        "Atlantic/Reykjavik", "Africa/Abidjan",
         "Atlantic/St_Helena", "Africa/Abidjan",
         "Australia/ACT", "Australia/Sydney",
         "Australia/Canberra", "Australia/Sydney",
+        "Australia/Currie", "Australia/Hobart",
         "Australia/LHI", "Australia/Lord_Howe",
         "Australia/NSW", "Australia/Sydney",
         "Australia/North", "Australia/Darwin",
@@ -908,19 +923,26 @@ class ZoneName {
         "Etc/UCT", "Etc/UTC",
         "Etc/Universal", "Etc/UTC",
         "Etc/Zulu", "Etc/UTC",
+        "Europe/Amsterdam", "Europe/Brussels",
         "Europe/Belfast", "Europe/London",
         "Europe/Bratislava", "Europe/Prague",
         "Europe/Busingen", "Europe/Zurich",
+        "Europe/Copenhagen", "Europe/Berlin",
         "Europe/Guernsey", "Europe/London",
         "Europe/Isle_of_Man", "Europe/London",
         "Europe/Jersey", "Europe/London",
+        "Europe/Kiev", "Europe/Kyiv",
         "Europe/Ljubljana", "Europe/Belgrade",
+        "Europe/Luxembourg", "Europe/Brussels",
         "Europe/Mariehamn", "Europe/Helsinki",
+        "Europe/Monaco", "Europe/Paris",
         "Europe/Nicosia", "Asia/Nicosia",
+        "Europe/Oslo", "Europe/Berlin",
         "Europe/Podgorica", "Europe/Belgrade",
         "Europe/San_Marino", "Europe/Rome",
         "Europe/Sarajevo", "Europe/Belgrade",
         "Europe/Skopje", "Europe/Belgrade",
+        "Europe/Stockholm", "Europe/Berlin",
         "Europe/Tiraspol", "Europe/Chisinau",
         "Europe/Vaduz", "Europe/Zurich",
         "Europe/Vatican", "Europe/Rome",
@@ -933,10 +955,15 @@ class ZoneName {
         "GMT0", "Etc/GMT",
         "Greenwich", "Etc/GMT",
         "Hongkong", "Asia/Hong_Kong",
-        "Iceland", "Atlantic/Reykjavik",
+        "Iceland", "Africa/Abidjan",
         "Indian/Antananarivo", "Africa/Nairobi",
+        "Indian/Christmas", "Asia/Bangkok",
+        "Indian/Cocos", "Asia/Yangon",
         "Indian/Comoro", "Africa/Nairobi",
+        "Indian/Kerguelen", "Indian/Maldives",
+        "Indian/Mahe", "Asia/Dubai",
         "Indian/Mayotte", "Africa/Nairobi",
+        "Indian/Reunion", "Asia/Dubai",
         "Iran", "Asia/Tehran",
         "Israel", "Asia/Jerusalem",
         "Jamaica", "America/Jamaica",
@@ -953,13 +980,20 @@ class ZoneName {
         "NZ-CHAT", "Pacific/Chatham",
         "Navajo", "America/Denver",
         "PRC", "Asia/Shanghai",
+        "Pacific/Chuuk", "Pacific/Port_Moresby",
+        "Pacific/Enderbury", "Pacific/Kanton",
+        "Pacific/Funafuti", "Pacific/Tarawa",
         "Pacific/Johnston", "Pacific/Honolulu",
+        "Pacific/Majuro", "Pacific/Tarawa",
         "Pacific/Midway", "Pacific/Pago_Pago",
-        "Pacific/Ponape", "Pacific/Pohnpei",
+        "Pacific/Pohnpei", "Pacific/Guadalcanal",
+        "Pacific/Ponape", "Pacific/Guadalcanal",
         "Pacific/Saipan", "Pacific/Guam",
         "Pacific/Samoa", "Pacific/Pago_Pago",
-        "Pacific/Truk", "Pacific/Chuuk",
-        "Pacific/Yap", "Pacific/Chuuk",
+        "Pacific/Truk", "Pacific/Port_Moresby",
+        "Pacific/Wake", "Pacific/Tarawa",
+        "Pacific/Wallis", "Pacific/Tarawa",
+        "Pacific/Yap", "Pacific/Port_Moresby",
         "Poland", "Europe/Warsaw",
         "Portugal", "Europe/Lisbon",
         "ROC", "Asia/Taipei",
@@ -978,7 +1012,6 @@ class ZoneName {
         "US/Michigan", "America/Detroit",
         "US/Mountain", "America/Denver",
         "US/Pacific", "America/Los_Angeles",
-        "US/Pacific-New", "America/Los_Angeles",
         "US/Samoa", "Pacific/Pago_Pago",
         "UTC", "Etc/UTC",
         "Universal", "Etc/UTC",
