@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2018, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -44,7 +44,7 @@ public class StandardDoclet implements Doclet {
     private final HtmlDoclet htmlDoclet;
 
     public StandardDoclet() {
-        htmlDoclet = new HtmlDoclet();
+        htmlDoclet = new HtmlDoclet(this);
     }
 
     @Override
