@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1998, 2020, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -112,17 +112,20 @@ public class DocPaths {
     /** The name of the default javascript file. */
     public static final DocPath JAVASCRIPT = DocPath.create("script.js");
 
+    /** The name of the stylesheet file overriding jQuery UI stylesheet. */
+    public static final DocPath JQUERY_OVERRIDES_CSS = DocPath.create("jquery-ui.overrides.css");
+
     /** The name of the directory for the jQuery. */
     public static final DocPath JQUERY_FILES = DocPath.create("jquery");
 
-    /** The name of the default jQuery stylesheet file. */
-    public static final DocPath JQUERY_STYLESHEET_FILE = DocPath.create("jquery-ui.css");
-
     /** The name of the default jQuery javascript file. */
-    public static final DocPath JQUERY_JS_3_4 = DocPath.create("jquery-3.4.1.js");
+    public static final DocPath JQUERY_JS = DocPath.create("jquery-3.6.0.min.js");
 
-    /** The name of the default jQuery javascript file. */
-    public static final DocPath JQUERY_JS = DocPath.create("jquery-ui.js");
+    /** The name of the default jQuery UI stylesheet file. */
+    public static final DocPath JQUERY_UI_CSS = DocPath.create("jquery-ui.min.css");
+
+    /** The name of the default jQuery UI javascript file. */
+    public static final DocPath JQUERY_UI_JS = DocPath.create("jquery-ui.min.js");
 
     /** The name of the default jszip javascript file. */
     public static final DocPath JSZIP = DocPath.create("jszip/dist/jszip.js");
