@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2022, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -126,6 +126,7 @@ module java.base {
     exports javax.security.auth.spi;
     exports javax.security.auth.x500;
     exports javax.security.cert;
+    exports com.sun.crypto.provider to jdk.crypto.cryptoki;
     exports com.sun.security.ntlm to java.security.sasl;
     exports jdk.internal to jdk.jfr;
     exports jdk.internal.access to
@@ -134,6 +135,7 @@ module java.base {
         java.management,
         java.naming,
         java.rmi,
+        jdk.jartool,
         jdk.jlink,
         jdk.net;
     exports jdk.internal.event to jdk.jfr;
@@ -159,6 +161,7 @@ module java.base {
         jdk.attach,
         jdk.charsets,
         jdk.compiler,
+        jdk.crypto.cryptoki,
         jdk.internal.vm.ci,
         jdk.jfr,
         jdk.jshell,
@@ -235,6 +238,9 @@ module java.base {
     exports sun.nio.cs to
         java.desktop,
         jdk.charsets;
+    exports sun.nio.fs to
+        jdk.net,
+        jdk.zipfs;
     exports sun.reflect.annotation to jdk.compiler;
     exports sun.reflect.generics.reflectiveObjects to java.desktop;
     exports sun.reflect.misc to
@@ -263,7 +269,9 @@ module java.base {
         java.security.jgss,
         jdk.crypto.cryptoki,
         jdk.security.auth;
-    exports sun.security.provider.certpath to java.naming;
+    exports sun.security.provider.certpath to
+        java.naming,
+        jdk.jartool;
     exports sun.security.rsa to jdk.crypto.cryptoki;
     exports sun.security.ssl to java.security.jgss;
     exports sun.security.timestamp to jdk.jartool;
