@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  */
 /**
@@ -28,10 +28,7 @@
  * ===========================================================================
  */
 /*
- * Copyright (c) 2005, 2019, Oracle and/or its affiliates. All rights reserved.
- */
-/*
- * $Id: XMLDSigRI.java 1833618 2018-06-15 17:36:20Z mullan $
+ * Copyright (c) 2005, Oracle and/or its affiliates. All rights reserved.
  */
 package org.jcp.xml.dsig.internal.dom;
 
@@ -74,13 +71,13 @@ public final class XMLDSigRI extends Provider {
         ProviderService(Provider p, String type, String algo, String cn,
             String[] aliases) {
             super(p, type, algo, cn,
-                (aliases == null? null : Arrays.asList(aliases)), null);
+                aliases == null ? null : Arrays.asList(aliases), null);
         }
 
         ProviderService(Provider p, String type, String algo, String cn,
-            String[] aliases, HashMap<String, String> attrs) {
+            String[] aliases, Map<String, String> attrs) {
             super(p, type, algo, cn,
-                  (aliases == null? null : Arrays.asList(aliases)), attrs);
+                  aliases == null ? null : Arrays.asList(aliases), attrs);
         }
 
         @Override
@@ -94,20 +91,20 @@ public final class XMLDSigRI extends Provider {
 
             String algo = getAlgorithm();
             try {
-                if (type.equals("XMLSignatureFactory")) {
-                    if (algo.equals("DOM")) {
+                if ("XMLSignatureFactory".equals(type)) {
+                    if ("DOM".equals(algo)) {
                         return new DOMXMLSignatureFactory();
                     }
-                } else if (type.equals("KeyInfoFactory")) {
-                    if (algo.equals("DOM")) {
+                } else if ("KeyInfoFactory".equals(type)) {
+                    if ("DOM".equals(algo)) {
                         return new DOMKeyInfoFactory();
                     }
-                } else if (type.equals("TransformService")) {
+                } else if ("TransformService".equals(type)) {
                     if (algo.equals(CanonicalizationMethod.INCLUSIVE) ||
                         algo.equals(CanonicalizationMethod.INCLUSIVE_WITH_COMMENTS)) {
                         return new DOMCanonicalXMLC14NMethod();
-                    } else if (algo.equals("http://www.w3.org/2006/12/xml-c14n11") ||
-                        algo.equals("http://www.w3.org/2006/12/xml-c14n11#WithComments")) {
+                    } else if ("http://www.w3.org/2006/12/xml-c14n11".equals(algo) ||
+                        "http://www.w3.org/2006/12/xml-c14n11#WithComments".equals(algo)) {
                         return new DOMCanonicalXMLC14N11Method();
                     } else if (algo.equals(CanonicalizationMethod.EXCLUSIVE) ||
                         algo.equals(CanonicalizationMethod.EXCLUSIVE_WITH_COMMENTS)) {
@@ -135,13 +132,13 @@ public final class XMLDSigRI extends Provider {
 
     public XMLDSigRI() {
         // This is the JDK XMLDSig provider, synced from
-        // Apache Santuario XML Security for Java, version 2.1.4
+        // Apache Santuario XML Security for Java, version 2.3.0
         super("XMLDSig", VER, INFO);
 
         final Provider p = this;
         AccessController.doPrivileged(new PrivilegedAction<Void>() {
             public Void run() {
-                HashMap<String, String> MECH_TYPE = new HashMap<>();
+                Map<String, String> MECH_TYPE = new HashMap<>();
                 MECH_TYPE.put("MechanismType", "DOM");
 
                 putService(new ProviderService(p, "XMLSignatureFactory",
