@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2019, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -33,22 +33,22 @@ import sun.nio.cs.SingleByte;
 import sun.nio.cs.HistoricallyNamedCharset;
 import static sun.nio.cs.CharsetMapping.*;
 
-public class ISO_8859_7 extends Charset implements HistoricallyNamedCharset
+public class ISO_8859_3 extends Charset implements HistoricallyNamedCharset
 {
-    public ISO_8859_7() {
-        super("ISO-8859-7", StandardCharsets.aliases_ISO_8859_7());
+    public ISO_8859_3() {
+        super("ISO-8859-3", StandardCharsets.aliases_ISO_8859_3());
     }
 
     public String historicalName() {
-        return "ISO8859_7";
+        return "ISO8859_3";
     }
 
     public boolean contains(Charset cs) {
-        return ((cs.name().equals("US-ASCII")) || (cs instanceof ISO_8859_7));
+        return ((cs.name().equals("US-ASCII")) || (cs instanceof ISO_8859_3));
     }
 
     public CharsetDecoder newDecoder() {
-        return new SingleByte.Decoder(this, b2c, true);
+        return new SingleByte.Decoder(this, b2c, true, false);
     }
 
     public CharsetEncoder newEncoder() {
@@ -60,18 +60,18 @@ public class ISO_8859_7 extends Charset implements HistoricallyNamedCharset
         "\u0088\u0089\u008A\u008B\u008C\u008D\u008E\u008F" +      // 0x88 - 0x8f
         "\u0090\u0091\u0092\u0093\u0094\u0095\u0096\u0097" +      // 0x90 - 0x97
         "\u0098\u0099\u009A\u009B\u009C\u009D\u009E\u009F" +      // 0x98 - 0x9f
-        "\u00A0\u2018\u2019\u00A3\u20AC\u20AF\u00A6\u00A7" +      // 0xa0 - 0xa7
-        "\u00A8\u00A9\u037A\u00AB\u00AC\u00AD\uFFFD\u2015" +      // 0xa8 - 0xaf
-        "\u00B0\u00B1\u00B2\u00B3\u0384\u0385\u0386\u00B7" +      // 0xb0 - 0xb7
-        "\u0388\u0389\u038A\u00BB\u038C\u00BD\u038E\u038F" +      // 0xb8 - 0xbf
-        "\u0390\u0391\u0392\u0393\u0394\u0395\u0396\u0397" +      // 0xc0 - 0xc7
-        "\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F" +      // 0xc8 - 0xcf
-        "\u03A0\u03A1\uFFFD\u03A3\u03A4\u03A5\u03A6\u03A7" +      // 0xd0 - 0xd7
-        "\u03A8\u03A9\u03AA\u03AB\u03AC\u03AD\u03AE\u03AF" +      // 0xd8 - 0xdf
-        "\u03B0\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7" +      // 0xe0 - 0xe7
-        "\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF" +      // 0xe8 - 0xef
-        "\u03C0\u03C1\u03C2\u03C3\u03C4\u03C5\u03C6\u03C7" +      // 0xf0 - 0xf7
-        "\u03C8\u03C9\u03CA\u03CB\u03CC\u03CD\u03CE\uFFFD" +      // 0xf8 - 0xff
+        "\u00A0\u0126\u02D8\u00A3\u00A4\uFFFD\u0124\u00A7" +      // 0xa0 - 0xa7
+        "\u00A8\u0130\u015E\u011E\u0134\u00AD\uFFFD\u017B" +      // 0xa8 - 0xaf
+        "\u00B0\u0127\u00B2\u00B3\u00B4\u00B5\u0125\u00B7" +      // 0xb0 - 0xb7
+        "\u00B8\u0131\u015F\u011F\u0135\u00BD\uFFFD\u017C" +      // 0xb8 - 0xbf
+        "\u00C0\u00C1\u00C2\uFFFD\u00C4\u010A\u0108\u00C7" +      // 0xc0 - 0xc7
+        "\u00C8\u00C9\u00CA\u00CB\u00CC\u00CD\u00CE\u00CF" +      // 0xc8 - 0xcf
+        "\uFFFD\u00D1\u00D2\u00D3\u00D4\u0120\u00D6\u00D7" +      // 0xd0 - 0xd7
+        "\u011C\u00D9\u00DA\u00DB\u00DC\u016C\u015C\u00DF" +      // 0xd8 - 0xdf
+        "\u00E0\u00E1\u00E2\uFFFD\u00E4\u010B\u0109\u00E7" +      // 0xe0 - 0xe7
+        "\u00E8\u00E9\u00EA\u00EB\u00EC\u00ED\u00EE\u00EF" +      // 0xe8 - 0xef
+        "\uFFFD\u00F1\u00F2\u00F3\u00F4\u0121\u00F6\u00F7" +      // 0xf0 - 0xf7
+        "\u011D\u00F9\u00FA\u00FB\u00FC\u016D\u015D\u02D9" +      // 0xf8 - 0xff
         "\u0000\u0001\u0002\u0003\u0004\u0005\u0006\u0007" +      // 0x00 - 0x07
         "\b\t\n\u000B\f\r\u000E\u000F" +      // 0x08 - 0x0f
         "\u0010\u0011\u0012\u0013\u0014\u0015\u0016\u0017" +      // 0x10 - 0x17
