@@ -25,6 +25,8 @@
 
 package sun.nio.fs;
 
+import sun.nio.cs.UTF_8;
+
 import jdk.internal.util.StaticProperty;
 
 import java.nio.file.*;
@@ -265,7 +267,7 @@ abstract class UnixFileStore
         Path file = Path.of(fstypes);
         try {
             try (ReadableByteChannel rbc = Files.newByteChannel(file)) {
-                result.load(Channels.newReader(rbc, "UTF-8"));
+                result.load(Channels.newReader(rbc, UTF_8.INSTANCE));
             }
         } catch (IOException x) {
         }
