@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2020, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -77,7 +77,6 @@ public class X509CRLEntryImpl extends X509CRLEntry
     private X500Principal certIssuer;
 
     private static final boolean isExplicit = false;
-    private static final long YR_2050 = 2524636800000L;
 
     /**
      * Constructs a revoked certificate entry using the given
@@ -162,7 +161,7 @@ public class X509CRLEntryImpl extends X509CRLEntry
                 // sequence { serialNumber, revocationDate, extensions }
                 serialNumber.encode(tmp);
 
-                if (revocationDate.getTime() < YR_2050) {
+                if (revocationDate.getTime() < CertificateValidity.YR_2050) {
                     tmp.putUTCTime(revocationDate);
                 } else {
                     tmp.putGeneralizedTime(revocationDate);
