@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -70,46 +70,6 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_en_MH extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] America_Eastern = new String[] {
-               "Eastern Standard Time",
-               "\u2205\u2205\u2205",
-               "Eastern Daylight Time",
-               "\u2205\u2205\u2205",
-               "Eastern Time",
-               "\u2205\u2205\u2205",
-            };
-        final String[] Hawaii_Aleutian = new String[] {
-               "Hawaii-Aleutian Standard Time",
-               "\u2205\u2205\u2205",
-               "Hawaii-Aleutian Daylight Time",
-               "\u2205\u2205\u2205",
-               "Hawaii-Aleutian Time",
-               "\u2205\u2205\u2205",
-            };
-        final String[] America_Central = new String[] {
-               "Central Standard Time",
-               "\u2205\u2205\u2205",
-               "Central Daylight Time",
-               "\u2205\u2205\u2205",
-               "Central Time",
-               "\u2205\u2205\u2205",
-            };
-        final String[] America_Mountain = new String[] {
-               "Mountain Standard Time",
-               "\u2205\u2205\u2205",
-               "Mountain Daylight Time",
-               "\u2205\u2205\u2205",
-               "Mountain Time",
-               "\u2205\u2205\u2205",
-            };
-        final String[] America_Pacific = new String[] {
-               "Pacific Standard Time",
-               "\u2205\u2205\u2205",
-               "Pacific Daylight Time",
-               "\u2205\u2205\u2205",
-               "Pacific Time",
-               "\u2205\u2205\u2205",
-            };
         final String[] Alaska = new String[] {
                "Alaska Standard Time",
                "\u2205\u2205\u2205",
@@ -126,6 +86,54 @@ public class TimeZoneNames_en_MH extends TimeZoneNamesBundle {
                "Atlantic Time",
                "\u2205\u2205\u2205",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] America_Central = new String[] {
+               "Central Standard Time",
+               "\u2205\u2205\u2205",
+               "Central Daylight Time",
+               "\u2205\u2205\u2205",
+               "Central Time",
+               "\u2205\u2205\u2205",
+            };
+        final String[] America_Eastern = new String[] {
+               "Eastern Standard Time",
+               "\u2205\u2205\u2205",
+               "Eastern Daylight Time",
+               "\u2205\u2205\u2205",
+               "Eastern Time",
+               "\u2205\u2205\u2205",
+            };
+        final String[] America_Pacific = new String[] {
+               "Pacific Standard Time",
+               "\u2205\u2205\u2205",
+               "Pacific Daylight Time",
+               "\u2205\u2205\u2205",
+               "Pacific Time",
+               "\u2205\u2205\u2205",
+            };
+        final String[] Hawaii_Aleutian = new String[] {
+               "Hawaii-Aleutian Standard Time",
+               "\u2205\u2205\u2205",
+               "Hawaii-Aleutian Daylight Time",
+               "\u2205\u2205\u2205",
+               "Hawaii-Aleutian Time",
+               "\u2205\u2205\u2205",
+            };
+        final String[] America_Mountain = new String[] {
+               "Mountain Standard Time",
+               "\u2205\u2205\u2205",
+               "Mountain Daylight Time",
+               "\u2205\u2205\u2205",
+               "Mountain Time",
+               "\u2205\u2205\u2205",
+            };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
             { "America/Denver", America_Mountain },
@@ -135,236 +143,152 @@ public class TimeZoneNames_en_MH extends TimeZoneNamesBundle {
             { "America/Indianapolis", America_Eastern },
             { "Pacific/Honolulu",
                 new String[] {
-                    "Hawaii Standard Time",
+                    "",
                     "\u2205\u2205\u2205",
-                    "Hawaii Daylight Time",
+                    "",
                     "\u2205\u2205\u2205",
-                    "Hawaii Time",
+                    "",
                     "\u2205\u2205\u2205",
                 }
             },
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Thule", Atlantic },
-            { "America/Curacao", Atlantic },
-            { "America/Marigot", Atlantic },
-            { "America/Martinique", Atlantic },
-            { "America/El_Salvador", America_Central },
-            { "America/Kentucky/Monticello", America_Eastern },
-            { "America/Coral_Harbour", America_Eastern },
-            { "America/Aruba", Atlantic },
-            { "America/North_Dakota/Center", America_Central },
-            { "America/Guatemala", America_Central },
-            { "America/Puerto_Rico", Atlantic },
-            { "America/Rankin_Inlet", America_Central },
-            { "America/Cayman", America_Eastern },
-            { "America/Belize", America_Central },
-            { "America/Panama", America_Eastern },
-            { "SystemV/CST6CDT", America_Central },
-            { "America/Tortola", Atlantic },
-            { "America/Indiana/Tell_City", America_Central },
-            { "America/Tijuana", America_Pacific },
-            { "America/Port_of_Spain", Atlantic },
-            { "America/Managua", America_Central },
-            { "America/Indiana/Petersburg", America_Eastern },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Nome", Alaska },
-            { "America/Ojinaga", America_Mountain },
-            { "America/Tegucigalpa", America_Central },
-            { "America/Rainy_River", America_Central },
-            { "SystemV/AST4", Atlantic },
-            { "America/Yellowknife", America_Mountain },
-            { "America/Juneau", Alaska },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Indiana/Vevay", America_Eastern },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Goose_Bay", Atlantic },
-            { "America/Thunder_Bay", America_Eastern },
-            { "America/Swift_Current", America_Central },
-            { "America/Grand_Turk", America_Eastern },
-            { "America/Metlakatla", Alaska },
-            { "America/Pangnirtung", America_Eastern },
+            { "UTC", EMPTY_ZONE },
+            { "AST", Alaska },
+            { "CST", America_Central },
             { "EST", America_Eastern },
-            { "America/Indiana/Marengo", America_Eastern },
-            { "America/Creston", America_Mountain },
-            { "MST", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Indiana/Vincennes", America_Eastern },
-            { "America/Whitehorse", America_Pacific },
-            { "America/Kralendijk", Atlantic },
-            { "America/Mexico_City", America_Central },
-            { "America/Antigua", Atlantic },
-            { "America/Montreal", America_Eastern },
-            { "America/Inuvik", America_Mountain },
-            { "America/Iqaluit", America_Eastern },
-            { "America/Matamoros", America_Central },
-            { "America/Blanc-Sablon", Atlantic },
-            { "America/Moncton", Atlantic },
-            { "America/Indiana/Winamac", America_Eastern },
-            { "SystemV/MST7MDT", America_Mountain },
-            { "America/St_Vincent", Atlantic },
-            { "PST8PDT", America_Pacific },
-            { "America/Grenada", Atlantic },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "CST6CDT", America_Central },
-            { "SystemV/HST10",
-                new String[] {
-                    "Hawaii Standard Time",
-                    "\u2205\u2205\u2205",
-                    "Hawaii Daylight Time",
-                    "\u2205\u2205\u2205",
-                    "Hawaii Time",
-                    "\u2205\u2205\u2205",
-                }
-            },
-            { "America/Menominee", America_Central },
-            { "America/Yakutat", Alaska },
-            { "America/Adak", Hawaii_Aleutian },
             { "HST",
                 new String[] {
-                    "Hawaii Standard Time",
+                    "",
                     "\u2205\u2205\u2205",
-                    "Hawaii Daylight Time",
+                    "",
                     "\u2205\u2205\u2205",
-                    "Hawaii Time",
+                    "",
                     "\u2205\u2205\u2205",
                 }
             },
-            { "America/Resolute", America_Central },
-            { "SystemV/YST9YDT", Alaska },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "SystemV/EST5", America_Eastern },
-            { "America/Merida", America_Central },
-            { "America/Edmonton", America_Mountain },
-            { "America/Santo_Domingo", Atlantic },
-            { "SystemV/MST7", America_Mountain },
-            { "America/St_Kitts", Atlantic },
-            { "America/Fort_Nelson", America_Mountain },
-            { "America/Glace_Bay", Atlantic },
-            { "America/Dominica", Atlantic },
-            { "America/Guadeloupe", Atlantic },
-            { "SystemV/PST8PDT", America_Pacific },
-            { "America/Port-au-Prince", America_Eastern },
-            { "America/St_Barthelemy", Atlantic },
-            { "America/Nipigon", America_Eastern },
-            { "America/Regina", America_Central },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Boise", America_Mountain },
-            { "America/North_Dakota/New_Salem", America_Central },
+            { "MST", America_Mountain },
+            { "PNT", America_Mountain },
+            { "PRT", Atlantic },
+            { "PST", America_Pacific },
+            { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
-            { "America/Dawson_Creek", America_Mountain },
-            { "America/St_Thomas", Atlantic },
-            { "Atlantic/Bermuda", Atlantic },
-            { "America/Anguilla", Atlantic },
-            { "America/Costa_Rica", America_Central },
-            { "America/Dawson", America_Pacific },
-            { "America/Shiprock", America_Mountain },
-            { "America/Winnipeg", America_Central },
-            { "Europe/Saratov",
+            { "MST7MDT", America_Mountain },
+            { "PST8PDT", America_Pacific },
+            { "America/Adak", Hawaii_Aleutian },
+            { "America/Nome", Alaska },
+            { "SystemV/AST4", Atlantic },
+            { "SystemV/CST6", America_Central },
+            { "SystemV/EST5", America_Eastern },
+            { "SystemV/MST7", America_Mountain },
+            { "America/Aruba", Atlantic },
+            { "America/Boise", America_Mountain },
+            { "America/Thule", Atlantic },
+            { "SystemV/HST10",
                 new String[] {
                     "",
+                    "\u2205\u2205\u2205",
                     "",
+                    "\u2205\u2205\u2205",
                     "",
-                    "",
-                    "",
-                    "",
+                    "\u2205\u2205\u2205",
                 }
             },
-            { "America/Indiana/Knox", America_Central },
+            { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
-            { "America/North_Dakota/Beulah", America_Central },
-            { "SystemV/AST4ADT", Atlantic },
-            { "America/St_Lucia", Atlantic },
-            { "America/Bahia_Banderas", America_Central },
-            { "America/Montserrat", Atlantic },
-            { "America/Cambridge_Bay", America_Mountain },
-            { "America/Toronto", America_Eastern },
-            { "MST7MDT", America_Mountain },
-            { "America/Barbados", Atlantic },
-            { "America/Monterrey", America_Central },
-            { "SystemV/EST5EDT", America_Eastern },
+            { "America/Cayman", America_Eastern },
+            { "America/Dawson", America_Pacific },
+            { "America/Inuvik", America_Mountain },
+            { "America/Juneau", Alaska },
+            { "America/Merida", America_Central },
             { "America/Nassau", America_Eastern },
-            { "America/Jamaica", America_Eastern },
-            { "America/Louisville", America_Eastern },
-            { "America/Lower_Princes", Atlantic },
-            { "America/Vancouver", America_Pacific },
+            { "America/Panama", America_Eastern },
+            { "America/Regina", America_Central },
+            { "America/Antigua", Atlantic },
+            { "America/Creston", America_Mountain },
+            { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
+            { "America/Grenada", Atlantic },
+            { "America/Iqaluit", America_Eastern },
+            { "America/Jamaica", America_Eastern },
+            { "America/Managua", America_Central },
+            { "America/Marigot", Atlantic },
+            { "America/Moncton", Atlantic },
+            { "America/Nipigon", America_Eastern },
+            { "America/Ojinaga", America_Mountain },
+            { "America/Tijuana", America_Pacific },
+            { "America/Toronto", America_Eastern },
+            { "America/Tortola", Atlantic },
+            { "America/Yakutat", Alaska },
+            { "SystemV/AST4ADT", Atlantic },
+            { "SystemV/CST6CDT", America_Central },
+            { "SystemV/EST5EDT", America_Eastern },
+            { "SystemV/MST7MDT", America_Mountain },
+            { "SystemV/PST8PDT", America_Pacific },
+            { "SystemV/YST9YDT", Alaska },
+            { "America/Anguilla", Atlantic },
+            { "America/Barbados", Atlantic },
+            { "America/Dominica", Atlantic },
+            { "America/Edmonton", America_Mountain },
+            { "America/Montreal", America_Eastern },
+            { "America/Resolute", America_Central },
+            { "America/Shiprock", America_Mountain },
+            { "America/St_Kitts", Atlantic },
+            { "America/St_Lucia", Atlantic },
+            { "America/Winnipeg", America_Central },
+            { "Atlantic/Bermuda", Atlantic },
             { "Pacific/Johnston", Hawaii_Aleutian },
-            { "SystemV/CST6", America_Central },
+            { "America/Glace_Bay", Atlantic },
+            { "America/Goose_Bay", Atlantic },
+            { "America/Guatemala", America_Central },
+            { "America/Matamoros", America_Central },
+            { "America/Menominee", America_Central },
+            { "America/Monterrey", America_Central },
+            { "America/St_Thomas", Atlantic },
+            { "America/Vancouver", America_Pacific },
+            { "America/Costa_Rica", America_Central },
+            { "America/Grand_Turk", America_Eastern },
+            { "America/Guadeloupe", Atlantic },
+            { "America/Kralendijk", Atlantic },
+            { "America/Louisville", America_Eastern },
+            { "America/Martinique", Atlantic },
+            { "America/Metlakatla", Alaska },
+            { "America/Montserrat", Atlantic },
+            { "America/St_Vincent", Atlantic },
+            { "America/Whitehorse", America_Pacific },
+            { "America/El_Salvador", America_Central },
+            { "America/Fort_Nelson", America_Mountain },
+            { "America/Mexico_City", America_Central },
+            { "America/Pangnirtung", America_Eastern },
+            { "America/Puerto_Rico", Atlantic },
+            { "America/Rainy_River", America_Central },
+            { "America/Tegucigalpa", America_Central },
+            { "America/Thunder_Bay", America_Eastern },
+            { "America/Yellowknife", America_Mountain },
+            { "America/Blanc-Sablon", Atlantic },
+            { "America/Dawson_Creek", America_Mountain },
+            { "America/Indiana/Knox", America_Central },
+            { "America/Rankin_Inlet", America_Central },
+            { "America/Cambridge_Bay", America_Mountain },
+            { "America/Coral_Harbour", America_Eastern },
+            { "America/Indiana/Vevay", America_Eastern },
+            { "America/Lower_Princes", Atlantic },
+            { "America/Port_of_Spain", Atlantic },
+            { "America/Santo_Domingo", Atlantic },
+            { "America/St_Barthelemy", Atlantic },
+            { "America/Swift_Current", America_Central },
+            { "America/Bahia_Banderas", America_Central },
+            { "America/Port-au-Prince", America_Eastern },
+            { "America/Indiana/Marengo", America_Eastern },
+            { "America/Indiana/Winamac", America_Eastern },
+            { "America/Indiana/Tell_City", America_Central },
+            { "America/Indiana/Vincennes", America_Eastern },
+            { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Kentucky/Monticello", America_Eastern },
+            { "America/North_Dakota/Beulah", America_Central },
+            { "America/North_Dakota/Center", America_Central },
+            { "America/North_Dakota/New_Salem", America_Central },
         };
         return data;
     }
