@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -70,156 +70,12 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] Cocos = new String[] {
-               "hora de las Islas Cocos",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Macquarie = new String[] {
-               "hora de la isla Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] America_Eastern = new String[] {
-               "hora est\u00e1ndar oriental",
-               "EST",
-               "hora de verano oriental",
-               "EDT",
-               "hora oriental",
-               "ET",
-            };
-        final String[] Hawaii_Aleutian = new String[] {
-               "hora est\u00e1ndar de Haw\u00e1i-Aleutianas",
-               "HAST",
-               "hora de verano de Haw\u00e1i-Aleutianas",
-               "HADT",
-               "hora de Haw\u00e1i-Aleutianas",
-               "HAT",
-            };
-        final String[] Indian_Ocean = new String[] {
-               "hora del Oc\u00e9ano \u00cdndico",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] America_Pacific = new String[] {
-               "hora est\u00e1ndar del Pac\u00edfico",
-               "PST",
-               "hora de verano del Pac\u00edfico",
-               "PDT",
-               "hora del Pac\u00edfico",
-               "PT",
-            };
-        final String[] Phoenix_Islands = new String[] {
-               "hora de las islas F\u00e9nix",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Europe_Western = new String[] {
-               "hora est\u00e1ndar de Europa occidental",
-               "\u2205\u2205\u2205",
-               "hora de verano de Europa occidental",
-               "\u2205\u2205\u2205",
-               "hora de Europa occidental",
-               "\u2205\u2205\u2205",
-            };
-        final String[] Solomon = new String[] {
-               "hora de las Islas Salom\u00f3n",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Norfolk = new String[] {
-               "hora de la isla Norfolk",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Marshall_Islands = new String[] {
-               "hora de las Islas Marshall",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Europe_Eastern = new String[] {
-               "hora est\u00e1ndar de Europa oriental",
-               "\u2205\u2205\u2205",
-               "hora de verano de Europa oriental",
-               "\u2205\u2205\u2205",
-               "hora de Europa oriental",
-               "\u2205\u2205\u2205",
-            };
-        final String[] Argentina_Western = new String[] {
-               "hora est\u00e1ndar de Argentina occidental",
-               "",
-               "hora de verano de Argentina occidental",
-               "",
-               "hora de Argentina occidental",
-               "",
-            };
-        final String[] Atlantic = new String[] {
-               "hora est\u00e1ndar del Atl\u00e1ntico",
-               "AST",
-               "hora de verano del Atl\u00e1ntico",
-               "ADT",
-               "hora del Atl\u00e1ntico",
-               "AT",
-            };
-        final String[] Easter = new String[] {
-               "hora est\u00e1ndar de la isla de Pascua",
-               "",
-               "hora de verano de la isla de Pascua",
-               "",
-               "hora de la isla de Pascua",
-               "",
-            };
-        final String[] America_Central = new String[] {
-               "hora est\u00e1ndar central",
-               "CST",
-               "hora de verano central",
-               "CDT",
-               "hora central",
-               "CT",
-            };
-        final String[] Gilbert_Islands = new String[] {
-               "hora de las islas Gilbert",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] America_Mountain = new String[] {
-               "hora est\u00e1ndar de las Monta\u00f1as Rocosas",
-               "MST",
-               "hora de verano de las Monta\u00f1as Rocosas",
-               "MDT",
-               "hora de las Monta\u00f1as Rocosas",
-               "MT",
-            };
-        final String[] Marquesas = new String[] {
-               "hora de las islas Marquesas",
-               "",
-               "",
+        final String[] Apia = new String[] {
+               "hora est\u00e1ndar de Apia",
                "",
+               "hora de verano de Apia",
                "",
+               "hora de Apia",
                "",
             };
         final String[] Wake = new String[] {
@@ -230,6 +86,14 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Cocos = new String[] {
+               "hora de las Islas Cocos",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "hora est\u00e1ndar de Alaska",
                "AKST",
@@ -238,14 +102,54 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "hora de Alaska",
                "AKT",
             };
-        final String[] Falkland = new String[] {
-               "hora est\u00e1ndar de las islas Malvinas",
+        final String[] Easter = new String[] {
+               "hora est\u00e1ndar de la isla de Pascua",
                "",
-               "hora de verano de las islas Malvinas",
+               "hora de verano de la isla de Pascua",
                "",
-               "hora de las islas Malvinas",
+               "hora de la isla de Pascua",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "hora universal coordinada",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Myanmar = new String[] {
+               "hora de Myanmar (Birmania)",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Norfolk = new String[] {
+               "hora de la isla Norfolk",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Solomon = new String[] {
+               "hora de las Islas Salom\u00f3n",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Atlantic = new String[] {
+               "hora est\u00e1ndar del Atl\u00e1ntico",
+               "AST",
+               "hora de verano del Atl\u00e1ntico",
+               "ADT",
+               "hora del Atl\u00e1ntico",
+               "AT",
+            };
         final String[] Chamorro = new String[] {
                "hora de Chamorro",
                "",
@@ -254,16 +158,24 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Apia = new String[] {
-               "hora est\u00e1ndar de Apia",
+        final String[] Falkland = new String[] {
+               "hora est\u00e1ndar de las islas Malvinas",
                "",
-               "hora de verano de Apia",
+               "hora de verano de las islas Malvinas",
                "",
-               "hora de Apia",
+               "hora de las islas Malvinas",
                "",
             };
-        final String[] Myanmar = new String[] {
-               "hora de Myanmar (Birmania)",
+        final String[] Macquarie = new String[] {
+               "hora de la isla Macquarie",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Marquesas = new String[] {
+               "hora de las islas Marquesas",
                "",
                "",
                "",
@@ -278,6 +190,102 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Indian_Ocean = new String[] {
+               "hora del Oc\u00e9ano \u00cdndico",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Europe_Eastern = new String[] {
+               "hora est\u00e1ndar de Europa oriental",
+               "\u2205\u2205\u2205",
+               "hora de verano de Europa oriental",
+               "\u2205\u2205\u2205",
+               "hora de Europa oriental",
+               "\u2205\u2205\u2205",
+            };
+        final String[] Europe_Western = new String[] {
+               "hora est\u00e1ndar de Europa occidental",
+               "\u2205\u2205\u2205",
+               "hora de verano de Europa occidental",
+               "\u2205\u2205\u2205",
+               "hora de Europa occidental",
+               "\u2205\u2205\u2205",
+            };
+        final String[] America_Central = new String[] {
+               "hora est\u00e1ndar central",
+               "CST",
+               "hora de verano central",
+               "CDT",
+               "hora central",
+               "CT",
+            };
+        final String[] America_Eastern = new String[] {
+               "hora est\u00e1ndar oriental",
+               "EST",
+               "hora de verano oriental",
+               "EDT",
+               "hora oriental",
+               "ET",
+            };
+        final String[] America_Pacific = new String[] {
+               "hora est\u00e1ndar del Pac\u00edfico",
+               "PST",
+               "hora de verano del Pac\u00edfico",
+               "PDT",
+               "hora del Pac\u00edfico",
+               "PT",
+            };
+        final String[] Gilbert_Islands = new String[] {
+               "hora de las islas Gilbert",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Hawaii_Aleutian = new String[] {
+               "hora est\u00e1ndar de Haw\u00e1i-Aleutianas",
+               "HAST",
+               "hora de verano de Haw\u00e1i-Aleutianas",
+               "HADT",
+               "hora de Haw\u00e1i-Aleutianas",
+               "HAT",
+            };
+        final String[] Phoenix_Islands = new String[] {
+               "hora de las islas F\u00e9nix",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] America_Mountain = new String[] {
+               "hora est\u00e1ndar de las Monta\u00f1as Rocosas",
+               "MST",
+               "hora de verano de las Monta\u00f1as Rocosas",
+               "MDT",
+               "hora de las Monta\u00f1as Rocosas",
+               "MT",
+            };
+        final String[] Marshall_Islands = new String[] {
+               "hora de las Islas Marshall",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Argentina_Western = new String[] {
+               "hora est\u00e1ndar de Argentina occidental",
+               "",
+               "hora de verano de Argentina occidental",
+               "",
+               "hora de Argentina occidental",
+               "",
+            };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
             { "America/Denver", America_Mountain },
@@ -300,90 +308,11 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Sitka", Alaska },
             { "Africa/Casablanca", Europe_Western },
             { "Europe/Bucharest", Europe_Eastern },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Marigot", Atlantic },
-            { "Pacific/Kwajalein", Marshall_Islands },
-            { "America/El_Salvador", America_Central },
-            { "America/Kentucky/Monticello", America_Eastern },
-            { "Africa/El_Aaiun", Europe_Western },
-            { "America/Coral_Harbour", America_Eastern },
-            { "Pacific/Marquesas", Marquesas },
-            { "Africa/Cairo", Europe_Eastern },
-            { "America/Aruba", Atlantic },
-            { "America/North_Dakota/Center", America_Central },
-            { "America/Guatemala", America_Central },
-            { "America/Cayman", America_Eastern },
-            { "America/Belize", America_Central },
-            { "America/Panama", America_Eastern },
-            { "America/Indiana/Tell_City", America_Central },
-            { "America/Tijuana", America_Pacific },
-            { "Pacific/Saipan", Chamorro },
-            { "America/Managua", America_Central },
-            { "America/Indiana/Petersburg", America_Eastern },
-            { "America/Ojinaga", America_Mountain },
-            { "America/Tegucigalpa", America_Central },
-            { "Asia/Damascus", Europe_Eastern },
-            { "America/Argentina/San_Luis", Argentina_Western },
-            { "Europe/Zaporozhye", Europe_Eastern },
-            { "timezone.excity.Asia/Dushanbe", "Dusamb\u00e9" },
-            { "Atlantic/Madeira", Europe_Western },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Thunder_Bay", America_Eastern },
-            { "America/Grand_Turk", America_Eastern },
-            { "Europe/Uzhgorod", Europe_Eastern },
-            { "America/Indiana/Marengo", America_Eastern },
-            { "America/Creston", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Mexico_City", America_Central },
-            { "Africa/Tripoli", Europe_Eastern },
-            { "timezone.excity.Asia/Barnaul", "Barnaul" },
-            { "America/Matamoros", America_Central },
-            { "America/Blanc-Sablon", Atlantic },
-            { "Europe/Kaliningrad", Europe_Eastern },
-            { "Europe/Lisbon", Europe_Western },
-            { "CST6CDT", America_Central },
-            { "Pacific/Easter", Easter },
-            { "Atlantic/Canary", Europe_Western },
-            { "SystemV/HST10",
-                new String[] {
-                    "hora est\u00e1ndar de Haw\u00e1i-Aleutianas",
-                    "HST",
-                    "hora de verano de Haw\u00e1i-Aleutianas",
-                    "HDT",
-                    "hora de Haw\u00e1i-Aleutianas",
-                    "HST",
-                }
-            },
-            { "America/Menominee", America_Central },
-            { "America/Adak", Hawaii_Aleutian },
-            { "Pacific/Norfolk", Norfolk },
+            { "UTC", ETC_UTC },
+            { "ART", Europe_Eastern },
+            { "AST", Alaska },
+            { "CST", America_Central },
+            { "EST", America_Eastern },
             { "HST",
                 new String[] {
                     "hora est\u00e1ndar de Haw\u00e1i-Aleutianas",
@@ -394,193 +323,182 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                     "HST",
                 }
             },
-            { "America/Resolute", America_Central },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "timezone.excity.Europe/Kirov", "Kirov" },
-            { "SystemV/EST5", America_Eastern },
-            { "America/Edmonton", America_Mountain },
-            { "America/Santo_Domingo", Atlantic },
-            { "America/Glace_Bay", Atlantic },
-            { "Europe/Kiev", Europe_Eastern },
-            { "America/Port-au-Prince", America_Eastern },
-            { "America/St_Barthelemy", Atlantic },
-            { "America/Nipigon", America_Eastern },
-            { "America/Regina", America_Central },
-            { "America/Dawson_Creek", America_Mountain },
-            { "Europe/Mariehamn", Europe_Eastern },
-            { "America/St_Thomas", Atlantic },
-            { "America/Anguilla", Atlantic },
-            { "Europe/Vilnius", Europe_Eastern },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Cancun", America_Eastern },
-            { "timezone.excity.America/Fort_Nelson", "Fort Nelson" },
-            { "America/St_Lucia", Atlantic },
-            { "America/Bahia_Banderas", America_Central },
-            { "America/Montserrat", Atlantic },
-            { "America/Cambridge_Bay", America_Mountain },
-            { "timezone.excity.America/St_Thomas", "St. Thomas" },
-            { "America/Barbados", Atlantic },
-            { "America/Louisville", America_Eastern },
-            { "America/Lower_Princes", Atlantic },
-            { "America/Vancouver", America_Pacific },
-            { "America/Detroit", America_Eastern },
-            { "Pacific/Johnston", Hawaii_Aleutian },
-            { "America/Thule", Atlantic },
-            { "America/Curacao", Atlantic },
-            { "America/Martinique", Atlantic },
-            { "Europe/Chisinau", Europe_Eastern },
-            { "America/Puerto_Rico", Atlantic },
-            { "America/Rankin_Inlet", America_Central },
-            { "SystemV/CST6CDT", America_Central },
-            { "America/Tortola", Atlantic },
-            { "America/Port_of_Spain", Atlantic },
-            { "Europe/Helsinki", Europe_Eastern },
-            { "Asia/Beirut", Europe_Eastern },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Nome", Alaska },
-            { "Indian/Chagos", Indian_Ocean },
-            { "Europe/Tallinn", Europe_Eastern },
-            { "America/Rainy_River", America_Central },
-            { "SystemV/AST4", Atlantic },
-            { "America/Yellowknife", America_Mountain },
-            { "Pacific/Enderbury", Phoenix_Islands },
-            { "America/Juneau", Alaska },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Indiana/Vevay", America_Eastern },
-            { "America/Goose_Bay", Atlantic },
-            { "America/Swift_Current", America_Central },
-            { "America/Metlakatla", Alaska },
-            { "America/Pangnirtung", America_Eastern },
-            { "EST", America_Eastern },
-            { "Europe/Sofia", Europe_Eastern },
+            { "MIT", Apia },
             { "MST", America_Mountain },
-            { "America/Indiana/Vincennes", America_Eastern },
-            { "America/Whitehorse", America_Pacific },
-            { "America/Kralendijk", Atlantic },
-            { "America/Antigua", Atlantic },
-            { "America/Montreal", America_Eastern },
-            { "America/Inuvik", America_Mountain },
-            { "America/Iqaluit", America_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
-            { "Asia/Nicosia", Europe_Eastern },
-            { "America/Moncton", Atlantic },
-            { "America/Indiana/Winamac", America_Eastern },
-            { "SystemV/MST7MDT", America_Mountain },
-            { "Asia/Pyongyang", Pyongyang },
-            { "America/St_Vincent", Atlantic },
-            { "Asia/Gaza", Europe_Eastern },
-            { "timezone.excity.Africa/Accra", "Acra" },
-            { "PST8PDT", America_Pacific },
-            { "America/Grenada", Atlantic },
-            { "Atlantic/Faeroe", Europe_Western },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Asia/Rangoon", Myanmar },
-            { "America/Yakutat", Alaska },
-            { "Indian/Cocos", Cocos },
-            { "SystemV/YST9YDT", Alaska },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Merida", America_Central },
-            { "SystemV/MST7", America_Mountain },
-            { "America/St_Kitts", Atlantic },
-            { "America/Fort_Nelson", America_Mountain },
-            { "Europe/Riga", Europe_Eastern },
-            { "America/Dominica", Atlantic },
-            { "America/Guadeloupe", Atlantic },
-            { "Asia/Hebron", Europe_Eastern },
-            { "SystemV/PST8PDT", America_Pacific },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Boise", America_Mountain },
-            { "America/North_Dakota/New_Salem", America_Central },
+            { "PNT", America_Mountain },
+            { "PRT", Atlantic },
+            { "PST", America_Pacific },
+            { "SST", Solomon },
+            { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
+            { "Etc/UTC", ETC_UTC },
+            { "MST7MDT", America_Mountain },
+            { "PST8PDT", America_Pacific },
+            { "Asia/Gaza", Europe_Eastern },
+            { "Asia/Amman", Europe_Eastern },
+            { "Asia/Beirut", Europe_Eastern },
+            { "Asia/Hebron", Europe_Eastern },
+            { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Riga", Europe_Eastern },
+            { "Africa/Cairo", Europe_Eastern },
+            { "America/Adak", Hawaii_Aleutian },
+            { "America/Nome", Alaska },
+            { "Asia/Nicosia", Europe_Eastern },
+            { "Asia/Rangoon", Myanmar },
+            { "Europe/Sofia", Europe_Eastern },
+            { "Indian/Cocos", Cocos },
+            { "Pacific/Apia", Apia },
             { "Pacific/Guam", Chamorro },
             { "Pacific/Wake", Wake },
-            { "Atlantic/Bermuda", Atlantic },
-            { "America/Costa_Rica", America_Central },
-            { "America/Dawson", America_Pacific },
-            { "America/Shiprock", America_Mountain },
-            { "America/Winnipeg", America_Central },
-            { "America/Indiana/Knox", America_Central },
-            { "America/North_Dakota/Beulah", America_Central },
-            { "timezone.excity.Europe/Ulyanovsk", "Ulyanovsk" },
-            { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
+            { "SystemV/AST4", Atlantic },
+            { "SystemV/CST6", America_Central },
+            { "SystemV/EST5", America_Eastern },
+            { "SystemV/MST7", America_Mountain },
+            { "America/Aruba", Atlantic },
+            { "America/Boise", America_Mountain },
+            { "America/Thule", Atlantic },
+            { "Asia/Damascus", Europe_Eastern },
+            { "Europe/Athens", Europe_Eastern },
+            { "Europe/Lisbon", Europe_Western },
+            { "Indian/Chagos", Indian_Ocean },
+            { "SystemV/HST10",
                 new String[] {
-                    "hora universal coordinada",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
+                    "hora est\u00e1ndar de Haw\u00e1i-Aleutianas",
+                    "HST",
+                    "hora de verano de Haw\u00e1i-Aleutianas",
+                    "HDT",
+                    "hora de Haw\u00e1i-Aleutianas",
+                    "HST",
                 }
             },
-            { "SystemV/AST4ADT", Atlantic },
-            { "Pacific/Apia", Apia },
-            { "America/Toronto", America_Eastern },
-            { "MST7MDT", America_Mountain },
-            { "America/Monterrey", America_Central },
-            { "SystemV/EST5EDT", America_Eastern },
-            { "Pacific/Majuro", Marshall_Islands },
+            { "Africa/Tripoli", Europe_Eastern },
+            { "America/Belize", America_Central },
+            { "America/Cancun", America_Eastern },
+            { "America/Cayman", America_Eastern },
+            { "America/Dawson", America_Pacific },
+            { "America/Inuvik", America_Mountain },
+            { "America/Juneau", Alaska },
+            { "America/Merida", America_Central },
             { "America/Nassau", America_Eastern },
-            { "timezone.excity.Europe/Astrakhan", "Astrakhan" },
+            { "America/Panama", America_Eastern },
+            { "America/Regina", America_Central },
+            { "Asia/Pyongyang", Pyongyang },
+            { "Europe/Tallinn", Europe_Eastern },
+            { "Europe/Vilnius", Europe_Eastern },
+            { "Pacific/Easter", Easter },
+            { "Pacific/Majuro", Marshall_Islands },
+            { "Pacific/Saipan", Chamorro },
+            { "Pacific/Tarawa", Gilbert_Islands },
+            { "Africa/El_Aaiun", Europe_Western },
+            { "America/Antigua", Atlantic },
+            { "America/Creston", America_Mountain },
+            { "America/Curacao", Atlantic },
+            { "America/Detroit", America_Eastern },
+            { "America/Grenada", Atlantic },
+            { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
-            { "Pacific/Guadalcanal", Solomon },
-            { "Europe/Athens", Europe_Eastern },
+            { "America/Managua", America_Central },
+            { "America/Marigot", Atlantic },
+            { "America/Moncton", Atlantic },
+            { "America/Nipigon", America_Eastern },
+            { "America/Ojinaga", America_Mountain },
+            { "America/Tijuana", America_Pacific },
+            { "America/Toronto", America_Eastern },
+            { "America/Tortola", Atlantic },
+            { "America/Yakutat", Alaska },
+            { "Atlantic/Canary", Europe_Western },
+            { "Atlantic/Faeroe", Europe_Western },
+            { "Europe/Chisinau", Europe_Eastern },
+            { "Europe/Helsinki", Europe_Eastern },
+            { "Europe/Uzhgorod", Europe_Eastern },
+            { "Pacific/Norfolk", Norfolk },
+            { "SystemV/AST4ADT", Atlantic },
+            { "SystemV/CST6CDT", America_Central },
+            { "SystemV/EST5EDT", America_Eastern },
+            { "SystemV/MST7MDT", America_Mountain },
+            { "SystemV/PST8PDT", America_Pacific },
+            { "SystemV/YST9YDT", Alaska },
+            { "America/Anguilla", Atlantic },
+            { "America/Barbados", Atlantic },
+            { "America/Dominica", Atlantic },
+            { "America/Edmonton", America_Mountain },
+            { "America/Montreal", America_Eastern },
+            { "America/Resolute", America_Central },
+            { "America/Shiprock", America_Mountain },
+            { "America/St_Kitts", Atlantic },
+            { "America/St_Lucia", Atlantic },
+            { "America/Winnipeg", America_Central },
+            { "Atlantic/Bermuda", Atlantic },
+            { "Atlantic/Madeira", Europe_Western },
             { "Atlantic/Stanley", Falkland },
-            { "SystemV/CST6", America_Central },
+            { "Europe/Mariehamn", Europe_Eastern },
+            { "Pacific/Johnston", Hawaii_Aleutian },
+            { "America/Glace_Bay", Atlantic },
+            { "America/Goose_Bay", Atlantic },
+            { "America/Guatemala", America_Central },
+            { "America/Matamoros", America_Central },
+            { "America/Menominee", America_Central },
+            { "America/Monterrey", America_Central },
+            { "America/St_Thomas", Atlantic },
+            { "America/Vancouver", America_Pacific },
+            { "Europe/Zaporozhye", Europe_Eastern },
+            { "Pacific/Enderbury", Phoenix_Islands },
+            { "Pacific/Kwajalein", Marshall_Islands },
+            { "Pacific/Marquesas", Marquesas },
+            { "America/Costa_Rica", America_Central },
+            { "America/Grand_Turk", America_Eastern },
+            { "America/Guadeloupe", Atlantic },
+            { "America/Kralendijk", Atlantic },
+            { "America/Louisville", America_Eastern },
+            { "America/Martinique", Atlantic },
+            { "America/Metlakatla", Alaska },
+            { "America/Montserrat", Atlantic },
+            { "America/St_Vincent", Atlantic },
+            { "America/Whitehorse", America_Pacific },
+            { "Europe/Kaliningrad", Europe_Eastern },
+            { "America/El_Salvador", America_Central },
+            { "America/Fort_Nelson", America_Mountain },
+            { "America/Mexico_City", America_Central },
+            { "America/Pangnirtung", America_Eastern },
+            { "America/Puerto_Rico", Atlantic },
+            { "America/Rainy_River", America_Central },
+            { "America/Tegucigalpa", America_Central },
+            { "America/Thunder_Bay", America_Eastern },
+            { "America/Yellowknife", America_Mountain },
+            { "Pacific/Guadalcanal", Solomon },
+            { "America/Blanc-Sablon", Atlantic },
+            { "America/Dawson_Creek", America_Mountain },
+            { "America/Indiana/Knox", America_Central },
+            { "America/Rankin_Inlet", America_Central },
+            { "Antarctica/Macquarie", Macquarie },
+            { "America/Cambridge_Bay", America_Mountain },
+            { "America/Coral_Harbour", America_Eastern },
+            { "America/Indiana/Vevay", America_Eastern },
+            { "America/Lower_Princes", Atlantic },
+            { "America/Port_of_Spain", Atlantic },
+            { "America/Santo_Domingo", Atlantic },
+            { "America/St_Barthelemy", Atlantic },
+            { "America/Swift_Current", America_Central },
+            { "America/Bahia_Banderas", America_Central },
+            { "America/Port-au-Prince", America_Eastern },
+            { "America/Indiana/Marengo", America_Eastern },
+            { "America/Indiana/Winamac", America_Eastern },
+            { "America/Indiana/Tell_City", America_Central },
+            { "America/Indiana/Vincennes", America_Eastern },
+            { "America/Argentina/San_Luis", Argentina_Western },
+            { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Kentucky/Monticello", America_Eastern },
+            { "America/North_Dakota/Beulah", America_Central },
+            { "America/North_Dakota/Center", America_Central },
+            { "timezone.excity.Africa/Accra", "Acra" },
+            { "timezone.excity.Asia/Barnaul", "Barnaul" },
+            { "timezone.excity.Europe/Kirov", "Kirov" },
+            { "timezone.excity.Asia/Dushanbe", "Dusamb\u00e9" },
+            { "America/North_Dakota/New_Salem", America_Central },
+            { "timezone.excity.Europe/Astrakhan", "Astrakhan" },
+            { "timezone.excity.Europe/Ulyanovsk", "Ulyanovsk" },
+            { "timezone.excity.America/St_Thomas", "St. Thomas" },
+            { "timezone.excity.America/Fort_Nelson", "Fort Nelson" },
         };
         return data;
     }
