@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -70,6 +70,22 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_kea extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] Atlantic = new String[] {
+               "Ora Padr\u00e3u di Atlantiku",
+               "",
+               "Ora di Ver\u00e3u di Atlantiku",
+               "",
+               "Ora di Atlantiku",
+               "",
+            };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Africa_Central = new String[] {
                "Ora di Afrika Sentral",
                "",
@@ -78,46 +94,6 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_CentralWestern = new String[] {
-               "Ora Padr\u00e3u di Australia Sentru-Osidental",
-               "",
-               "Ora di Ver\u00e3u di Australia Sentru-Osidental",
-               "",
-               "Ora di Autralia Sentru-Osidental",
-               "",
-            };
-        final String[] Europe_Central = new String[] {
-               "Ora Padr\u00e3u di Europa Sentral",
-               "",
-               "Ora di Ver\u00e3u di Europa Sentral",
-               "",
-               "Ora di Europa Sentral",
-               "",
-            };
-        final String[] America_Eastern = new String[] {
-               "Ora Oriental Padr\u00e3u",
-               "",
-               "Ora Oriental di Ver\u00e3u",
-               "",
-               "Ora Oriental",
-               "",
-            };
-        final String[] Australia_Central = new String[] {
-               "Ora Padr\u00e3u di Australia Sentral",
-               "",
-               "Ora di Ver\u00e3u di Australia Sentral",
-               "",
-               "Ora di Australia Sentral",
-               "",
-            };
-        final String[] America_Pacific = new String[] {
-               "Ora di Pasifiku Padr\u00e3u",
-               "",
-               "Ora di Pasifiku di Ver\u00e3u",
-               "",
-               "Ora di Pasifiku",
-               "",
-            };
         final String[] Africa_Eastern = new String[] {
                "Ora di Afrika Oriental",
                "",
@@ -126,12 +102,20 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Europe_Western = new String[] {
-               "Ora Padr\u00e3u di Europa Osidental",
+        final String[] Africa_Western = new String[] {
+               "Ora Padr\u00e3u di Afrika Osidental",
                "",
-               "Ora di Ver\u00e3u di Europa Osidental",
+               "Ora di Ver\u00e3o di Afrika Osidental",
                "",
-               "Ora di Europa Osidental",
+               "Ora di Afrika Osidental",
+               "",
+            };
+        final String[] Europe_Central = new String[] {
+               "Ora Padr\u00e3u di Europa Sentral",
+               "",
+               "Ora di Ver\u00e3u di Europa Sentral",
+               "",
+               "Ora di Europa Sentral",
                "",
             };
         final String[] Europe_Eastern = new String[] {
@@ -142,20 +126,12 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "Ora di Europa Oriental",
                "",
             };
-        final String[] Atlantic = new String[] {
-               "Ora Padr\u00e3u di Atlantiku",
+        final String[] Europe_Western = new String[] {
+               "Ora Padr\u00e3u di Europa Osidental",
                "",
-               "Ora di Ver\u00e3u di Atlantiku",
+               "Ora di Ver\u00e3u di Europa Osidental",
                "",
-               "Ora di Atlantiku",
-               "",
-            };
-        final String[] Africa_Western = new String[] {
-               "Ora Padr\u00e3u di Afrika Osidental",
-               "",
-               "Ora di Ver\u00e3o di Afrika Osidental",
-               "",
-               "Ora di Afrika Osidental",
+               "Ora di Europa Osidental",
                "",
             };
         final String[] Africa_Southern = new String[] {
@@ -166,14 +142,6 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Western = new String[] {
-               "Ora Padr\u00e3u di Australia Osidental",
-               "",
-               "Ora di Ver\u00e3u di Australia Osidental",
-               "",
-               "Ora di Australia Osidental",
-               "",
-            };
         final String[] America_Central = new String[] {
                "Ora Sentral Padr\u00e3u",
                "",
@@ -182,6 +150,38 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "Ora Sentral",
                "",
             };
+        final String[] America_Eastern = new String[] {
+               "Ora Oriental Padr\u00e3u",
+               "",
+               "Ora Oriental di Ver\u00e3u",
+               "",
+               "Ora Oriental",
+               "",
+            };
+        final String[] America_Pacific = new String[] {
+               "Ora di Pasifiku Padr\u00e3u",
+               "",
+               "Ora di Pasifiku di Ver\u00e3u",
+               "",
+               "Ora di Pasifiku",
+               "",
+            };
+        final String[] America_Mountain = new String[] {
+               "Ora di Montanha Padr\u00e3u",
+               "",
+               "Ora di Ver\u00e3u di Montanha",
+               "",
+               "Ora di Montanha",
+               "",
+            };
+        final String[] Australia_Central = new String[] {
+               "Ora Padr\u00e3u di Australia Sentral",
+               "",
+               "Ora di Ver\u00e3u di Australia Sentral",
+               "",
+               "Ora di Australia Sentral",
+               "",
+            };
         final String[] Australia_Eastern = new String[] {
                "Ora Padr\u00e3u di Australia Oriental",
                "",
@@ -190,12 +190,20 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "Ora di Australia Oriental",
                "",
             };
-        final String[] America_Mountain = new String[] {
-               "Ora di Montanha Padr\u00e3u",
+        final String[] Australia_Western = new String[] {
+               "Ora Padr\u00e3u di Australia Osidental",
                "",
-               "Ora di Ver\u00e3u di Montanha",
+               "Ora di Ver\u00e3u di Australia Osidental",
                "",
-               "Ora di Montanha",
+               "Ora di Australia Osidental",
+               "",
+            };
+        final String[] Australia_CentralWestern = new String[] {
+               "Ora Padr\u00e3u di Australia Sentru-Osidental",
+               "",
+               "Ora di Ver\u00e3u di Australia Sentru-Osidental",
+               "",
+               "Ora di Autralia Sentru-Osidental",
                "",
             };
         final Object[][] data = new Object[][] {
@@ -209,307 +217,228 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "Europe/Paris", Europe_Central },
             { "Africa/Casablanca", Europe_Western },
             { "Europe/Bucharest", Europe_Eastern },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Africa/Nairobi", Africa_Eastern },
-            { "Africa/Libreville", Africa_Western },
-            { "America/Marigot", Atlantic },
-            { "Africa/Maputo", Africa_Central },
-            { "America/El_Salvador", America_Central },
-            { "America/Kentucky/Monticello", America_Eastern },
-            { "Africa/El_Aaiun", Europe_Western },
-            { "America/Coral_Harbour", America_Eastern },
-            { "Africa/Cairo", Europe_Eastern },
-            { "Africa/Mbabane", Africa_Southern },
-            { "America/Aruba", Atlantic },
-            { "America/North_Dakota/Center", America_Central },
-            { "America/Guatemala", America_Central },
-            { "Australia/Hobart", Australia_Eastern },
-            { "America/Cayman", America_Eastern },
-            { "America/Belize", America_Central },
-            { "America/Panama", America_Eastern },
-            { "Europe/San_Marino", Europe_Central },
-            { "America/Indiana/Tell_City", America_Central },
-            { "America/Tijuana", America_Pacific },
-            { "America/Managua", America_Central },
-            { "America/Indiana/Petersburg", America_Eastern },
-            { "Europe/Brussels", Europe_Central },
-            { "Africa/Douala", Africa_Western },
-            { "America/Ojinaga", America_Mountain },
-            { "Europe/Warsaw", Europe_Central },
-            { "America/Tegucigalpa", America_Central },
-            { "Asia/Damascus", Europe_Eastern },
-            { "Europe/Luxembourg", Europe_Central },
-            { "Africa/Brazzaville", Africa_Western },
-            { "Europe/Zaporozhye", Europe_Eastern },
-            { "Africa/Porto-Novo", Africa_Western },
-            { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Atlantic/Madeira", Europe_Western },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Thunder_Bay", America_Eastern },
-            { "America/Grand_Turk", America_Eastern },
-            { "Africa/Addis_Ababa", Africa_Eastern },
-            { "Europe/Uzhgorod", Europe_Eastern },
-            { "America/Indiana/Marengo", America_Eastern },
-            { "Africa/Kigali", Africa_Central },
-            { "America/Creston", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Mexico_City", America_Central },
-            { "Africa/Tunis", Europe_Central },
-            { "Europe/Andorra", Europe_Central },
-            { "Africa/Tripoli", Europe_Eastern },
-            { "Indian/Comoro", Africa_Eastern },
-            { "America/Matamoros", America_Central },
-            { "America/Blanc-Sablon", Atlantic },
-            { "Europe/Kaliningrad", Europe_Eastern },
-            { "Africa/Windhoek", Africa_Central },
-            { "Europe/Lisbon", Europe_Western },
-            { "Europe/Oslo", Europe_Central },
-            { "Africa/Mogadishu", Africa_Eastern },
-            { "Australia/Perth", Australia_Western },
-            { "CST6CDT", America_Central },
-            { "Atlantic/Canary", Europe_Western },
-            { "America/Menominee", America_Central },
-            { "Europe/Malta", Europe_Central },
-            { "America/Resolute", America_Central },
-            { "Africa/Asmera", Africa_Eastern },
-            { "Africa/Kampala", Africa_Eastern },
-            { "Europe/Busingen", Europe_Central },
-            { "SystemV/EST5", America_Eastern },
-            { "Africa/Malabo", Africa_Western },
-            { "America/Edmonton", America_Mountain },
-            { "Europe/Podgorica", Europe_Central },
-            { "Europe/Skopje", Europe_Central },
-            { "Africa/Bujumbura", Africa_Central },
-            { "America/Santo_Domingo", Atlantic },
-            { "Europe/Sarajevo", Europe_Central },
-            { "America/Glace_Bay", Atlantic },
-            { "Africa/Lagos", Africa_Western },
-            { "Europe/Kiev", Europe_Eastern },
-            { "Europe/Rome", Europe_Central },
-            { "America/Port-au-Prince", America_Eastern },
-            { "America/St_Barthelemy", Atlantic },
-            { "Africa/Luanda", Africa_Western },
-            { "America/Nipigon", America_Eastern },
-            { "America/Regina", America_Central },
-            { "Atlantic/Jan_Mayen", Europe_Central },
-            { "America/Dawson_Creek", America_Mountain },
-            { "Africa/Algiers", Europe_Central },
-            { "Europe/Mariehamn", Europe_Eastern },
-            { "America/St_Thomas", Atlantic },
-            { "Europe/Zurich", Europe_Central },
-            { "America/Anguilla", Atlantic },
-            { "Europe/Vilnius", Europe_Eastern },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Cancun", America_Eastern },
-            { "Africa/Maseru", Africa_Southern },
-            { "Europe/Gibraltar", Europe_Central },
-            { "Africa/Kinshasa", Africa_Western },
-            { "Australia/Sydney", Australia_Eastern },
-            { "Africa/Lubumbashi", Africa_Central },
-            { "America/St_Lucia", Atlantic },
-            { "Europe/Madrid", Europe_Central },
-            { "America/Bahia_Banderas", America_Central },
-            { "America/Montserrat", Atlantic },
-            { "America/Cambridge_Bay", America_Mountain },
-            { "Indian/Antananarivo", Africa_Eastern },
-            { "Europe/Vaduz", Europe_Central },
-            { "Australia/Brisbane", Australia_Eastern },
-            { "Indian/Mayotte", Africa_Eastern },
-            { "America/Barbados", Atlantic },
-            { "America/Louisville", America_Eastern },
-            { "America/Lower_Princes", Atlantic },
-            { "America/Vancouver", America_Pacific },
-            { "Africa/Blantyre", Africa_Central },
-            { "America/Detroit", America_Eastern },
-            { "Europe/Ljubljana", Europe_Central },
-            { "America/Thule", Atlantic },
-            { "America/Curacao", Atlantic },
-            { "Africa/Lusaka", Africa_Central },
-            { "America/Martinique", Atlantic },
-            { "Europe/Berlin", Europe_Central },
-            { "Europe/Chisinau", Europe_Eastern },
-            { "America/Puerto_Rico", Atlantic },
-            { "America/Rankin_Inlet", America_Central },
-            { "Europe/Stockholm", Europe_Central },
-            { "SystemV/CST6CDT", America_Central },
-            { "America/Tortola", Atlantic },
-            { "Europe/Budapest", Europe_Central },
-            { "Australia/Eucla", Australia_CentralWestern },
-            { "Europe/Zagreb", Europe_Central },
-            { "America/Port_of_Spain", Atlantic },
-            { "Europe/Helsinki", Europe_Eastern },
-            { "Asia/Beirut", Europe_Eastern },
-            { "Africa/Harare", Africa_Central },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Africa/Sao_Tome", Africa_Western },
-            { "Europe/Tallinn", Europe_Eastern },
-            { "Africa/Khartoum", Africa_Central },
-            { "Africa/Johannesburg", Africa_Southern },
-            { "Africa/Ndjamena", Africa_Western },
-            { "Africa/Bangui", Africa_Western },
-            { "America/Rainy_River", America_Central },
-            { "Europe/Belgrade", Europe_Central },
-            { "SystemV/AST4", Atlantic },
-            { "America/Yellowknife", America_Mountain },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Indiana/Vevay", America_Eastern },
-            { "Africa/Juba", Africa_Eastern },
-            { "Africa/Ceuta", Europe_Central },
-            { "America/Goose_Bay", Atlantic },
-            { "America/Swift_Current", America_Central },
-            { "Australia/Adelaide", Australia_Central },
-            { "America/Pangnirtung", America_Eastern },
-            { "Africa/Djibouti", Africa_Eastern },
+            { "UTC", EMPTY_ZONE },
+            { "ACT", Australia_Central },
+            { "AET", Australia_Eastern },
+            { "ART", Europe_Eastern },
+            { "CAT", Africa_Central },
+            { "CST", America_Central },
+            { "EAT", Africa_Eastern },
+            { "ECT", Europe_Central },
             { "EST", America_Eastern },
-            { "Europe/Sofia", Europe_Eastern },
             { "MST", America_Mountain },
-            { "Africa/Niamey", Africa_Western },
-            { "Europe/Prague", Europe_Central },
-            { "America/Indiana/Vincennes", America_Eastern },
-            { "America/Whitehorse", America_Pacific },
-            { "America/Kralendijk", Atlantic },
-            { "America/Antigua", Atlantic },
-            { "America/Montreal", America_Eastern },
-            { "America/Inuvik", America_Mountain },
-            { "America/Iqaluit", America_Eastern },
-            { "Asia/Nicosia", Europe_Eastern },
-            { "America/Moncton", Atlantic },
-            { "Africa/Gaborone", Africa_Central },
-            { "America/Indiana/Winamac", America_Eastern },
-            { "SystemV/MST7MDT", America_Mountain },
-            { "America/St_Vincent", Atlantic },
-            { "Asia/Gaza", Europe_Eastern },
+            { "PNT", America_Mountain },
+            { "PRT", Atlantic },
+            { "PST", America_Pacific },
+            { "CST6CDT", America_Central },
+            { "EST5EDT", America_Eastern },
+            { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
-            { "timezone.excity.Etc/Unknown", "Sidadi Diskonxedu" },
+            { "Asia/Gaza", Europe_Eastern },
+            { "Asia/Amman", Europe_Eastern },
+            { "Africa/Juba", Africa_Eastern },
+            { "Asia/Beirut", Europe_Eastern },
+            { "Asia/Hebron", Europe_Eastern },
+            { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Oslo", Europe_Central },
+            { "Europe/Riga", Europe_Eastern },
+            { "Europe/Rome", Europe_Central },
+            { "Africa/Cairo", Europe_Eastern },
+            { "Africa/Ceuta", Europe_Central },
+            { "Africa/Lagos", Africa_Western },
+            { "Africa/Tunis", Europe_Central },
+            { "Asia/Nicosia", Europe_Eastern },
+            { "Europe/Malta", Europe_Central },
+            { "Europe/Sofia", Europe_Eastern },
+            { "Europe/Vaduz", Europe_Central },
+            { "SystemV/AST4", Atlantic },
+            { "SystemV/CST6", America_Central },
+            { "SystemV/EST5", America_Eastern },
+            { "SystemV/MST7", America_Mountain },
+            { "Africa/Asmera", Africa_Eastern },
+            { "Africa/Bangui", Africa_Western },
+            { "Africa/Douala", Africa_Western },
+            { "Africa/Harare", Africa_Central },
+            { "Africa/Kigali", Africa_Central },
+            { "Africa/Luanda", Africa_Western },
+            { "Africa/Lusaka", Africa_Central },
+            { "Africa/Malabo", Africa_Western },
+            { "Africa/Maputo", Africa_Central },
+            { "Africa/Maseru", Africa_Southern },
+            { "Africa/Niamey", Africa_Western },
+            { "America/Aruba", Atlantic },
+            { "America/Boise", America_Mountain },
+            { "America/Thule", Atlantic },
+            { "Asia/Damascus", Europe_Eastern },
+            { "Europe/Athens", Europe_Eastern },
+            { "Europe/Berlin", Europe_Central },
+            { "Europe/Lisbon", Europe_Western },
+            { "Europe/Madrid", Europe_Central },
+            { "Europe/Monaco", Europe_Central },
+            { "Europe/Prague", Europe_Central },
+            { "Europe/Skopje", Europe_Central },
+            { "Europe/Tirane", Europe_Central },
+            { "Europe/Vienna", Europe_Central },
+            { "Europe/Warsaw", Europe_Central },
+            { "Europe/Zagreb", Europe_Central },
+            { "Europe/Zurich", Europe_Central },
+            { "Indian/Comoro", Africa_Eastern },
+            { "Africa/Algiers", Europe_Central },
+            { "Africa/Kampala", Africa_Eastern },
+            { "Africa/Mbabane", Africa_Southern },
+            { "Africa/Nairobi", Africa_Eastern },
+            { "Africa/Tripoli", Europe_Eastern },
+            { "America/Belize", America_Central },
+            { "America/Cancun", America_Eastern },
+            { "America/Cayman", America_Eastern },
+            { "America/Dawson", America_Pacific },
+            { "America/Inuvik", America_Mountain },
+            { "America/Merida", America_Central },
+            { "America/Nassau", America_Eastern },
+            { "America/Panama", America_Eastern },
+            { "America/Regina", America_Central },
+            { "Europe/Andorra", Europe_Central },
+            { "Europe/Tallinn", Europe_Eastern },
+            { "Europe/Vatican", Europe_Central },
+            { "Europe/Vilnius", Europe_Eastern },
+            { "Indian/Mayotte", Africa_Eastern },
+            { "Africa/Blantyre", Africa_Central },
+            { "Africa/Djibouti", Africa_Eastern },
+            { "Africa/El_Aaiun", Europe_Western },
+            { "Africa/Gaborone", Africa_Central },
+            { "Africa/Khartoum", Africa_Central },
+            { "Africa/Kinshasa", Africa_Western },
+            { "Africa/Ndjamena", Africa_Western },
+            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Windhoek", Africa_Central },
+            { "America/Antigua", Atlantic },
+            { "America/Creston", America_Mountain },
+            { "America/Curacao", Atlantic },
+            { "America/Detroit", America_Eastern },
             { "America/Grenada", Atlantic },
-            { "Australia/Darwin", Australia_Central },
+            { "America/Iqaluit", America_Eastern },
+            { "America/Jamaica", America_Eastern },
+            { "America/Managua", America_Central },
+            { "America/Marigot", Atlantic },
+            { "America/Moncton", Atlantic },
+            { "America/Nipigon", America_Eastern },
+            { "America/Ojinaga", America_Mountain },
+            { "America/Tijuana", America_Pacific },
+            { "America/Toronto", America_Eastern },
+            { "America/Tortola", Atlantic },
+            { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/Perth", Australia_Western },
+            { "Europe/Belgrade", Europe_Central },
+            { "Europe/Brussels", Europe_Central },
+            { "Europe/Budapest", Europe_Central },
+            { "Europe/Busingen", Europe_Central },
+            { "Europe/Chisinau", Europe_Eastern },
+            { "Europe/Helsinki", Europe_Eastern },
+            { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Uzhgorod", Europe_Eastern },
+            { "SystemV/AST4ADT", Atlantic },
+            { "SystemV/CST6CDT", America_Central },
+            { "SystemV/EST5EDT", America_Eastern },
+            { "SystemV/MST7MDT", America_Mountain },
+            { "SystemV/PST8PDT", America_Pacific },
+            { "Africa/Bujumbura", Africa_Central },
+            { "Africa/Mogadishu", Africa_Eastern },
+            { "America/Anguilla", Atlantic },
+            { "America/Barbados", Atlantic },
+            { "America/Dominica", Atlantic },
+            { "America/Edmonton", America_Mountain },
+            { "America/Montreal", America_Eastern },
+            { "America/Resolute", America_Central },
+            { "America/Shiprock", America_Mountain },
+            { "America/St_Kitts", Atlantic },
+            { "America/St_Lucia", Atlantic },
+            { "America/Winnipeg", America_Central },
+            { "Atlantic/Bermuda", Atlantic },
+            { "Atlantic/Madeira", Europe_Western },
+            { "Australia/Currie", Australia_Eastern },
+            { "Australia/Darwin", Australia_Central },
+            { "Australia/Hobart", Australia_Eastern },
+            { "Australia/Sydney", Australia_Eastern },
+            { "Europe/Amsterdam", Europe_Central },
+            { "Europe/Gibraltar", Europe_Central },
+            { "Europe/Ljubljana", Europe_Central },
+            { "Europe/Mariehamn", Europe_Eastern },
+            { "Europe/Podgorica", Europe_Central },
+            { "Europe/Stockholm", Europe_Central },
+            { "Africa/Libreville", Africa_Western },
+            { "Africa/Lubumbashi", Africa_Central },
+            { "Africa/Porto-Novo", Africa_Western },
+            { "America/Glace_Bay", Atlantic },
+            { "America/Goose_Bay", Atlantic },
+            { "America/Guatemala", America_Central },
+            { "America/Matamoros", America_Central },
+            { "America/Menominee", America_Central },
+            { "America/Monterrey", America_Central },
+            { "America/St_Thomas", Atlantic },
+            { "America/Vancouver", America_Pacific },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
-            { "Europe/Vienna", Europe_Central },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Merida", America_Central },
-            { "Europe/Tirane", Europe_Central },
-            { "timezone.excity.America/Blanc-Sablon", "Blank-Sablon" },
-            { "SystemV/MST7", America_Mountain },
-            { "America/St_Kitts", Atlantic },
-            { "Arctic/Longyearbyen", Europe_Central },
-            { "America/Fort_Nelson", America_Mountain },
-            { "Australia/Broken_Hill", Australia_Central },
-            { "Europe/Riga", Europe_Eastern },
-            { "America/Dominica", Atlantic },
-            { "America/Guadeloupe", Atlantic },
-            { "Asia/Hebron", Europe_Eastern },
-            { "SystemV/PST8PDT", America_Pacific },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Boise", America_Mountain },
-            { "Australia/Currie", Australia_Eastern },
-            { "America/North_Dakota/New_Salem", America_Central },
-            { "EST5EDT", America_Eastern },
-            { "Australia/Melbourne", Australia_Eastern },
-            { "Atlantic/Bermuda", Atlantic },
+            { "Europe/Luxembourg", Europe_Central },
+            { "Europe/San_Marino", Europe_Central },
+            { "Europe/Zaporozhye", Europe_Eastern },
+            { "Africa/Addis_Ababa", Africa_Eastern },
+            { "Africa/Brazzaville", Africa_Western },
             { "America/Costa_Rica", America_Central },
-            { "America/Dawson", America_Pacific },
-            { "America/Shiprock", America_Mountain },
-            { "America/Winnipeg", America_Central },
-            { "Europe/Amsterdam", Europe_Central },
-            { "America/Indiana/Knox", America_Central },
-            { "America/North_Dakota/Beulah", America_Central },
-            { "Europe/Vatican", Europe_Central },
-            { "Asia/Amman", Europe_Eastern },
-            { "SystemV/AST4ADT", Atlantic },
-            { "America/Toronto", America_Eastern },
+            { "America/Grand_Turk", America_Eastern },
+            { "America/Guadeloupe", Atlantic },
+            { "America/Kralendijk", Atlantic },
+            { "America/Louisville", America_Eastern },
+            { "America/Martinique", Atlantic },
+            { "America/Montserrat", Atlantic },
+            { "America/St_Vincent", Atlantic },
+            { "America/Whitehorse", America_Pacific },
+            { "Atlantic/Jan_Mayen", Europe_Central },
+            { "Australia/Adelaide", Australia_Central },
+            { "Australia/Brisbane", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "MST7MDT", America_Mountain },
-            { "America/Monterrey", America_Central },
-            { "SystemV/EST5EDT", America_Eastern },
-            { "America/Nassau", America_Eastern },
-            { "America/Jamaica", America_Eastern },
-            { "Europe/Athens", Europe_Eastern },
-            { "Europe/Monaco", Europe_Central },
-            { "SystemV/CST6", America_Central },
+            { "Europe/Kaliningrad", Europe_Eastern },
+            { "Africa/Johannesburg", Africa_Southern },
+            { "America/El_Salvador", America_Central },
+            { "America/Fort_Nelson", America_Mountain },
+            { "America/Mexico_City", America_Central },
+            { "America/Pangnirtung", America_Eastern },
+            { "America/Puerto_Rico", Atlantic },
+            { "America/Rainy_River", America_Central },
+            { "America/Tegucigalpa", America_Central },
+            { "America/Thunder_Bay", America_Eastern },
+            { "America/Yellowknife", America_Mountain },
+            { "Arctic/Longyearbyen", Europe_Central },
+            { "Australia/Melbourne", Australia_Eastern },
+            { "Indian/Antananarivo", Africa_Eastern },
+            { "Africa/Dar_es_Salaam", Africa_Eastern },
+            { "America/Blanc-Sablon", Atlantic },
+            { "America/Dawson_Creek", America_Mountain },
+            { "America/Indiana/Knox", America_Central },
+            { "America/Rankin_Inlet", America_Central },
+            { "America/Cambridge_Bay", America_Mountain },
+            { "America/Coral_Harbour", America_Eastern },
+            { "America/Indiana/Vevay", America_Eastern },
+            { "America/Lower_Princes", Atlantic },
+            { "America/Port_of_Spain", Atlantic },
+            { "America/Santo_Domingo", Atlantic },
+            { "America/St_Barthelemy", Atlantic },
+            { "America/Swift_Current", America_Central },
+            { "Australia/Broken_Hill", Australia_Central },
+            { "America/Bahia_Banderas", America_Central },
+            { "America/Port-au-Prince", America_Eastern },
+            { "America/Indiana/Marengo", America_Eastern },
+            { "America/Indiana/Winamac", America_Eastern },
+            { "America/Indiana/Tell_City", America_Central },
+            { "America/Indiana/Vincennes", America_Eastern },
+            { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Kentucky/Monticello", America_Eastern },
+            { "America/North_Dakota/Beulah", America_Central },
+            { "America/North_Dakota/Center", America_Central },
+            { "timezone.excity.Etc/Unknown", "Sidadi Diskonxedu" },
+            { "America/North_Dakota/New_Salem", America_Central },
+            { "timezone.excity.America/Blanc-Sablon", "Blank-Sablon" },
         };
         return data;
     }
